aind\_metadata\_mapper package
==============================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   aind_metadata_mapper.bergamo
   aind_metadata_mapper.bruker
   aind_metadata_mapper.dynamic_routing
   aind_metadata_mapper.exaspim
   aind_metadata_mapper.fip
   aind_metadata_mapper.mesoscope
   aind_metadata_mapper.open_ephys
   aind_metadata_mapper.smartspim
   aind_metadata_mapper.stimulus
   aind_metadata_mapper.u19

Submodules
----------

aind\_metadata\_mapper.core module
----------------------------------

.. automodule:: aind_metadata_mapper.core
   :members:
   :undoc-members:
   :show-inheritance:

aind\_metadata\_mapper.core\_models module
------------------------------------------

.. automodule:: aind_metadata_mapper.core_models
   :members:
   :undoc-members:
   :show-inheritance:

aind\_metadata\_mapper.gather\_metadata module
----------------------------------------------

.. automodule:: aind_metadata_mapper.gather_metadata
   :members:
   :undoc-members:
   :show-inheritance:

aind\_metadata\_mapper.models module
------------------------------------

.. automodule:: aind_metadata_mapper.models
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: aind_metadata_mapper
   :members:
   :undoc-members:
   :show-inheritance:
